@@ -1,4 +1,4 @@
-/*$Id: ap.h,v 24.16 2004/01/11 02:47:28 al Exp $  -*- C++ -*-
+/*$Id: ap.h,v 25.94 2006/08/08 03:22:25 al Exp $  -*- C++ -*-
  * Copyright (C) 2001 Albert Davis
  * Author: Albert Davis <aldavis@ieee.org>
  *
@@ -16,11 +16,12 @@
  *
  * You should have received a copy of the GNU General Public License
  * along with this program; if not, write to the Free Software
- * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA
- * 02111-1307, USA.
+ * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA
+ * 02110-1301, USA.
  *------------------------------------------------------------------
  * stuff for the "ap" family of parsing functions
  */
+//testing=script,sparse 2006.07.17
 #ifndef AP_H
 #define AP_H
 #include "md.h"
@@ -51,9 +52,9 @@ private:
   static enum MATCH_STYLE {msPARTIAL, msIGNORE_CASE, msEXACT} _ms;
 public:
   // control
-  static void set_partial() {_ms = msPARTIAL;}
-  static void set_ignore_case() {_ms = msIGNORE_CASE;}
-  static void set_exact() {_ms = msEXACT;}
+  static void set_partial()	{untested(); _ms = msPARTIAL;}
+  static void set_ignore_case()	{untested(); _ms = msIGNORE_CASE;}
+  static void set_exact()	{untested(); _ms = msEXACT;}
 
   // construction, destruction, and re-construction
   explicit    CS(CS_FILE, const std::string& name, int i=0);
@@ -77,7 +78,7 @@ public:
   // status - may consume whitespace only
   bool	      ns_more()const	{return peek()!='\0';}
   bool	      more()		{skipbl(); return ns_more();}
-  bool	      end()		{return !more();}
+  bool	      is_end()		{return !more();}
 
   // control
   CS&	      reset(int c=0)	{_cnt=c; _ok=true; return *this;}
@@ -101,7 +102,9 @@ public:
   // character tests - non-consuming, no _ok
   bool	      match1(char c)const{return (peek()==c);}
   bool	      match1(const std::string& c)const
-			{return ns_more() && strchr(c.c_str(),peek());}
+		{return ns_more() && strchr(c.c_str(),peek());}
+  int	      find1(const std::string& c)const
+	{return ((ns_more()) ? c.find_first_of(peek()) : std::string::npos);}
   bool	      is_xdigit()const
 		{untested(); return (match1("0123456789abcdefABCDEF"));}
   bool	      is_digit()const	{return (match1("0123456789"));}
@@ -109,23 +112,28 @@ public:
   bool	      is_float()const	{return (match1("+-.0123456789"));}
   bool	      is_argsym()const	{return (match1("*?$%_&@"));}
   bool	      is_alpha()const	{return !!isalpha(toascii(peek()));}
+  bool	      is_alnum()const   {return !!isalnum(toascii(peek()));}
   bool	      is_term(const std::string& t = ",=(){};")
 	{char c=peek(); return (c=='\0' || isspace(c) || match1(t));}
 
   // conversions (ap_convert.cc) always consuming
-  char	      ctoc() {char c=_cmd[_cnt]; if(_cnt<=_length) {++_cnt;} return c;}
+  char	      ctoc();
   void        ctostr(char*,int,const std::string&);
-  std::string ctos(const std::string& term=",=(){};", char b='"', char e='"');
+  std::string ctos(const std::string& term=",=(){};",
+		   const std::string& b="\"",
+		   const std::string& e="\"");
   std::string get_to(const std::string& term);
 
   // conversions (ap_convert.cc) consumes if successful, sets _ok
   double      ctof();
+  bool	      ctob();
   int	      ctoi();
   unsigned    ctou();
   int	      ctoo();
   int	      ctox();
   double      ctopf()			{return std::abs(ctof());}
-  CS&	      operator>>(char&x)	{x=ctoc();return *this;}
+  CS&	      operator>>(bool&x)	{x=ctob();return *this;}
+  CS&	      operator>>(char&x)	{untested(); x=ctoc();return *this;}
   CS&         operator>>(int&x)		{x=ctoi();return *this;}
   CS&         operator>>(unsigned&x)	{untested(); x=ctou();return *this;}
   CS&         operator>>(double&x)	{x=ctof();return *this;}
@@ -141,51 +149,99 @@ public:
   CS&	      skiparg();
   CS&	      skipto1(const std::string&);
   CS&	      skipto1(char);
-  CS&	      skipcom()		{return skip1b(",=");}
-  CS&	      skiplparen()	{return skip1b("([");}
-  CS&	      skiprparen()	{return skip1b(")]");}
-  CS&	      skipequal()	{return skip1b("=");}
+  CS&	      skipcom()		{return skip1b(",");}
+  CS&	      operator>>(const char x)	{return skip1b(x);}
+  CS&	      operator>>(const char* x)	{untested(); return skip1b(x);}
 };	
 /*--------------------------------------------------------------------------*/
 /*--------------------------------------------------------------------------*/
 // these are non-member to provide a consistent interface,
 // like the templates to follow
-bool get(CS& cmd, const std::string&, bool*, AP_MOD=mNONE);
-bool get(CS& cmd, const std::string&, int*,  AP_MOD=mNONE, int=0);
-bool get(CS& cmd, const std::string& key, double* val, AP_MOD, double=0);
+bool get(CS& cmd, const std::string&, bool*);
+bool get(CS& cmd, const std::string&, int*,    AP_MOD=mNONE, int=0);
 /*--------------------------------------------------------------------------*/
 template <class T>
 inline bool get(CS& cmd, const std::string& key, T* val)
 {
-  {if (cmd.dmatch(key)) {
-    cmd >> *val;
+  if (cmd.dmatch(key)) {
+    cmd >> '=' >> *val;
     return true;
   }else{
     return false;
-  }}
+  }
+}
+/*--------------------------------------------------------------------------*/
+template <class T>
+inline bool ap_get_adjust(T* val, AP_MOD mod)
+{
+  switch(mod) {
+  case mNONE:	  untested(); /*nothing*/	break;
+  case mSCALE:    unreachable();		break;
+  case mOFFSET:	  unreachable();		break;
+  case mINVERT:   untested(); *val = 1 / *val;	break;
+  case mPOSITIVE: *val = std::abs(*val);	break;
+  case mOCTAL:	  unreachable();		break;
+  case mHEX:  	  unreachable();		break;
+  }
+  return true;
+}
+/*--------------------------------------------------------------------------*/
+template <class T>
+inline bool ap_get_adjust(T* val, AP_MOD mod, T scale)
+{untested();
+  switch(mod) {
+  case mNONE:	  untested(); /*nothing*/	break;
+  case mSCALE:    untested(); *val *= scale;	break;
+  case mOFFSET:	  untested(); *val += scale;	break;
+  case mINVERT:   untested(); *val = 1 / *val;	break;
+  case mPOSITIVE: untested(); *val = std::abs(*val);	break;
+  case mOCTAL:	  unreachable();		break;
+  case mHEX:  	  unreachable();		break;
+  }
+  return true;
+}
+/*--------------------------------------------------------------------------*/
+template <class T>
+inline bool get(CS& cmd, const std::string& key, T* val, AP_MOD mod)
+{
+  return get(cmd, key, val) && ap_get_adjust(val, mod);
+}
+/*--------------------------------------------------------------------------*/
+template <class T>
+inline bool get(CS& cmd, const std::string& key, T* val, AP_MOD mod, T scale)
+{
+  return get(cmd, key, val) && ap_get_adjust(val, mod, scale);
 }
 /*--------------------------------------------------------------------------*/
 template <class T>
 inline bool scan_get(CS& cmd, const std::string& key, T* val)
 {
-  {if (cmd.dscan(key)) {
-    cmd >> *val;
+  if (cmd.dscan(key)) {
+    cmd >> '=' >> *val;
     return true;
   }else{
     return false;
-  }}
+  }
 }
 /*--------------------------------------------------------------------------*/
 template <class T>
 inline bool set(CS& cmd, const std::string& key, T* val, T newval)
 {
-  {if (cmd.dmatch(key)) {
+  if (cmd.dmatch(key)) {
     *val = newval;
     return true;
   }else{
     return false;
-  }}
+  }
+}
+/*--------------------------------------------------------------------------*/
+template <class T>
+inline CS& operator>>(CS& cmd, T& val)
+{
+  val.parse(cmd);
+  return cmd;
 }
 /*--------------------------------------------------------------------------*/
 /*--------------------------------------------------------------------------*/
+/*--------------------------------------------------------------------------*/
 #endif
