@@ -1,4 +1,4 @@
-/*$Id: ap_construct.cc,v 21.14 2002/03/26 09:20:25 al Exp $ -*- C++ -*-
+/*$Id: ap_construct.cc,v 25.94 2006/08/08 03:22:25 al Exp $ -*- C++ -*-
  * Copyright (C) 2001 Albert Davis
  * Author: Albert Davis <aldavis@ieee.org>
  *
@@ -16,12 +16,12 @@
  *
  * You should have received a copy of the GNU General Public License
  * along with this program; if not, write to the Free Software
- * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA
- * 02111-1307, USA.
+ * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA
+ * 02110-1301, USA.
  *------------------------------------------------------------------
  * construction, copy, etc.
  */
-#include <fcntl.h>
+//testing=script,sparse 2006.07.17
 #include "ap.h"
 /*--------------------------------------------------------------------------*/
 CS::CS(CS_FILE, const std::string& name, int i)
@@ -36,8 +36,9 @@ CS::CS(CS_FILE, const std::string& name, int i)
   _name = new char[name.length()+1];
   strcpy(_name, name.c_str());
   int f = open(_name, O_RDONLY);
-  if (f == EOF) {
+  if (f == EOF) {untested();
     error(bERROR, name + ':' + strerror(errno));
+  }else{
   }
   _length = lseek(f, off_t(0), SEEK_END);
   lseek(f, off_t(0), SEEK_SET);
@@ -61,6 +62,7 @@ CS::CS(const std::string& s, int i)
   strcpy(_cmd, s.c_str());
 }
 /*--------------------------------------------------------------------------*/
+#if 0
 CS::CS(const CS& p)
   :_name(0),
    _cmd(0),
@@ -69,19 +71,22 @@ CS::CS(const CS& p)
    _length(p._length),
    _begin_match(0),
    _end_match(0)
-{
-  if (p._name) {
+{untested();
+  if (p._name) {untested();
     _name = new char[strlen(p._name)+1];
     strcpy(_name, p._name);
+  }else{untested();
   }
   _cmd = new char[_length+1];
   strcpy(_cmd, p._cmd);
 }
+#endif
 /*--------------------------------------------------------------------------*/
 CS& CS::operator=(const std::string& s)
-{
-  if (_cmd){
+{untested();
+  if (_cmd) {untested();
     delete[] _cmd;
+  }else{untested();
   }
   _cnt = 0;
   _ok = true;
@@ -91,18 +96,22 @@ CS& CS::operator=(const std::string& s)
   return *this;
 }    
 /*--------------------------------------------------------------------------*/
+#if 0
 CS& CS::operator=(const CS& p)
-{
+{untested();
   assert(&p != this);
-  if (p._name) {
-    if (_name) {
+  if (p._name) {untested();
+    if (_name) {untested();
       delete[] _name;
+    }else{untested();
     }
     _name = new char[strlen(p._name)+1];
     strcpy(_name, p._name);
+  }else{untested();
   }
-  if (_cmd){
+  if (_cmd) {untested();
     delete[] _cmd;
+  }else{untested();
   }
   _cnt = p._cnt;
   _ok = p._ok;
@@ -111,5 +120,6 @@ CS& CS::operator=(const CS& p)
   strcpy(_cmd, p._cmd);
   return *this;
 }
+#endif
 /*--------------------------------------------------------------------------*/
 /*--------------------------------------------------------------------------*/
