@@ -1,4 +1,4 @@
-/*$Id: c_sim.cc,v 21.14 2002/03/26 09:20:25 al Exp $ -*- C++ -*-
+/*$Id: c_sim.cc,v 25.94 2006/08/08 03:22:25 al Exp $ -*- C++ -*-
  * Copyright (C) 2001 Albert Davis
  * Author: Albert Davis <aldavis@ieee.org>
  *
@@ -16,11 +16,12 @@
  *
  * You should have received a copy of the GNU General Public License
  * along with this program; if not, write to the Free Software
- * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA
- * 02111-1307, USA.
+ * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA
+ * 02110-1301, USA.
  *------------------------------------------------------------------
  * command interface functions associated with the SIM base class
  */
+//testing=script 2006.07.17
 #include "s_ac.h"
 #include "s_dc.h"
 #include "s_tr.h"
@@ -32,7 +33,7 @@ void CMD::dc(CS& cmd)		{static DC dc;		dc.command(cmd);}
 void CMD::fourier(CS& cmd)	{static FOURIER fo;	fo.command(cmd);}
 void CMD::op(CS& cmd)		{static OP op;		op.command(cmd);}
 void CMD::tr(CS& cmd)		{static TRANSIENT tr;	tr.command(cmd);}
-void CMD::mark(CS&)		{SIM::freezetime = true;}
+void CMD::mark(CS&)		{untested();SIM::freezetime = true;}
 void CMD::unmark(CS&)		{SIM::freezetime = false;}
 /*--------------------------------------------------------------------------*/
 /*--------------------------------------------------------------------------*/
