@@ -1,4 +1,4 @@
-/*$Id: d_coment.cc,v 21.14 2002/03/26 09:20:25 al Exp $ -*- C++ -*-
+/*$Id: d_coment.cc,v 25.94 2006/08/08 03:22:25 al Exp $ -*- C++ -*-
  * Copyright (C) 2001 Albert Davis
  * Author: Albert Davis <aldavis@ieee.org>
  *
@@ -16,29 +16,30 @@
  *
  * You should have received a copy of the GNU General Public License
  * along with this program; if not, write to the Free Software
- * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA
- * 02111-1307, USA.
+ * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA
+ * 02110-1301, USA.
  *------------------------------------------------------------------
  * processing for COMMENT netlist item (pseudo-device)
  * Old C style hack:
  * uses the space in a "card" struct, overwrites the leftover
  * Maybe the class hierarchy needs another level
  */
-#include "ap.h"
+//testing=script,complete 2006.07.17
 #include "d_coment.h"
 /*--------------------------------------------------------------------------*/
-//	void	DEV_COMMENT::parse(CS& cmd);
+//	void	DEV_COMMENT::parse_spice(CS& cmd);
 //	void	DEV_COMMENT::print(int,int)const;
 /*--------------------------------------------------------------------------*/
-void DEV_COMMENT::parse(CS& cmd)
+void DEV_COMMENT::parse_spice(CS& cmd)
 {
   _s = cmd.fullstring();
 }
 /*--------------------------------------------------------------------------*/
-void DEV_COMMENT::print(OMSTREAM& where, int)const
+void DEV_COMMENT::print_spice(OMSTREAM& where, int)const
 {
-  if (_s[0] != '*'  ||  _s[1] != '+'){
+  if (_s[0] != '*'  ||  _s[1] != '+') {
     where << _s << '\n';
+  }else{
   }
   // Suppress printing of comment lines starting with "*+".
   // These are generated as a way to display calculated values.
