@@ -1,4 +1,4 @@
-/*$Id: d_dot.cc,v 21.14 2002/03/26 09:20:25 al Exp $ -*- C++ -*-
+/*$Id: d_dot.cc,v 25.94 2006/08/08 03:22:25 al Exp $ -*- C++ -*-
  * Copyright (C) 2001 Albert Davis
  * Author: Albert Davis <aldavis@ieee.org>
  *
@@ -16,40 +16,40 @@
  *
  * You should have received a copy of the GNU General Public License
  * along with this program; if not, write to the Free Software
- * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA
- * 02111-1307, USA.
+ * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA
+ * 02110-1301, USA.
  *------------------------------------------------------------------
  * processing for DOTCARD netlist item (pseudo-device)
  * "parsing" a "dotcard" will execute it.
  * What actually happens (usually either to preset or really do)
  * depends on the option "run_mode", which depends on what command is running.
  */
+//testing=script 2006.07.17
 #include "c_comand.h"
-#include "ap.h"
 #include "d_dot.h"
 /*--------------------------------------------------------------------------*/
-//	void	DEV_DOT::parse(CS& cmd);
+//	void	DEV_DOT::parse_spice(CS& cmd);
 //	void	DEV_DOT::print(int,int)const;
 /*--------------------------------------------------------------------------*/
-void DEV_DOT::parse(CS& cmd)
+void DEV_DOT::parse_spice(CS& cmd)
 {
   _s = cmd.fullstring();
-  switch (ENV::run_mode){
+  switch (ENV::run_mode) {
   case rIGNORE:
     unreachable();
     /*nothing*/
     break;
+  case rBATCH: untested();
+  case rINTERACTIVE: untested();
   case rPRESET:
-  case rINTERACTIVE:
   case rSCRIPT:
-  case rBATCH:
     cmd.skip1b(".");
     CMD::cmdproc(cmd.tail());
     break;
   }
 }
 /*--------------------------------------------------------------------------*/
-void DEV_DOT::print(OMSTREAM& where, int)const
+void DEV_DOT::print_spice(OMSTREAM& where, int)const
 {
   where << _s << '\n';
 }
