@@ -1,4 +1,4 @@
-/*$Id: io_getln.cc,v 21.14 2002/03/26 09:20:25 al Exp $ -*- C++ -*-
+/*$Id: io_getln.cc,v 25.94 2006/08/08 03:22:25 al Exp $ -*- C++ -*-
  * Copyright (C) 2001 Albert Davis
  * Author: Albert Davis <aldavis@ieee.org>
  *
@@ -16,8 +16,8 @@
  *
  * You should have received a copy of the GNU General Public License
  * along with this program; if not, write to the Free Software
- * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA
- * 02111-1307, USA.
+ * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA
+ * 02110-1301, USA.
  *------------------------------------------------------------------
  * get a bunch of lines, from a file
  * interface is just line fgets.
@@ -26,8 +26,8 @@
  * is always a line ahead
  * start with + is extension line, spice compatibility.
  */
+//testing=script 2006.07.17
 #include "l_lib.h"
-// testing=nonstrict
 /*--------------------------------------------------------------------------*/
 std::string getlines(FILE *fileptr)
 {
@@ -36,29 +36,29 @@ std::string getlines(FILE *fileptr)
   std::string s;
 
   bool more = true;  // get another line (extend)
-  while (more){
+  while (more) {
     char buffer[buffer_size+1];
     char* got = fgets(buffer, buffer_size, fileptr);
-    {if (!got){ // probably end of file
+    if (!got) { // probably end of file
       more = false;
     }else{
       trim(buffer);
       int count = strlen(buffer);
-      {if (buffer[count-1] == '\\'){
+      if (buffer[count-1] == '\\') {
 	untested();
 	buffer[count-1] = '\0';
       }else{
 	int c = fgetc(fileptr);
-	{if (c == '+'){
+	if (c == '+') {
 	  more = true;
 	}else{
 	  more = false;
 	  ungetc(c,fileptr);
-	}}
-      }}
+	}
+      }
       s += buffer;
       s += ' ';
-    }}
+    }
   }
   return s;
 }
