@@ -1,4 +1,4 @@
-/*$Id: l_denoise.h,v 21.14 2002/03/26 09:20:25 al Exp $ -*- C++ -*-
+/*$Id: l_denoise.h,v 25.94 2006/08/08 03:22:25 al Exp $ -*- C++ -*-
  * Copyright (C) 2001 Albert Davis
  * Author: Albert Davis <aldavis@ieee.org>
  *
@@ -16,12 +16,13 @@
  *
  * You should have received a copy of the GNU General Public License
  * along with this program; if not, write to the Free Software
- * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA
- * 02111-1307, USA.
+ * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA
+ * 02110-1301, USA.
  *------------------------------------------------------------------
  * functions to "de-noise" arithmetic
  * attempt to get rid of noise due to roundoff
  */
+//testing=script,complete 2006.07.13
 #ifndef L_DENOISE_H
 #define L_DENOISE_H
 #include "u_opt.h"
@@ -29,6 +30,9 @@
 /* fixzero: force numbers near zero to zero - changes thru pointer */
 inline void fixzero(double *z, double r)
 {
+  assert(z);
+  assert(*z == *z);
+  assert(r == r);
   if (std::abs(*z) < std::abs(r*OPT::roundofftol)) {
     *z=0.;
   }
@@ -37,20 +41,29 @@ inline void fixzero(double *z, double r)
 /* fixzero: force numbers near zero to zero - returns value */
 inline double fixzero(double z, double r)
 {
+  assert(z == z);
+  assert(r == r);
   return (std::abs(z) < std::abs(r*OPT::roundofftol)) ? 0. : z;
 }
 /*--------------------------------------------------------------------------*/
 /* dn_diff: de-noised difference */
 inline double dn_diff(double a, double b)
 {
+  assert(a == a);
+  assert(b == b);
   return fixzero(a-b, a);
 }
 /*--------------------------------------------------------------------------*/
+#if 0
 /* dn_sum: de-noised sum */
 inline double dn_sum(double a, double b)
 {
+  untested();
+  assert(a == a);
+  assert(b == b);
   return fixzero(a+b, a);
 }
+#endif
 /*--------------------------------------------------------------------------*/
 /*--------------------------------------------------------------------------*/
 #endif
