@@ -1,4 +1,4 @@
-/*$Id: l_ftos.cc,v 21.14 2002/03/26 09:20:25 al Exp $ -*- C++ -*-
+/*$Id: l_ftos.cc,v 25.94 2006/08/08 03:22:25 al Exp $ -*- C++ -*-
  * Copyright (C) 2001 Albert Davis
  * Author: Albert Davis <aldavis@ieee.org>
  *
@@ -16,8 +16,8 @@
  *
  * You should have received a copy of the GNU General Public License
  * along with this program; if not, write to the Free Software
- * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA
- * 02111-1307, USA.
+ * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA
+ * 02110-1301, USA.
  *------------------------------------------------------------------
  * float to string
  * builds string representing floating number
@@ -36,44 +36,16 @@
  * there is a finite pool, so repeated calls work, to a point.
  * after that, the space is overwritten, every POOLSIZE calls
  */
+//testing=script 2005.10.11
 #include "l_lib.h"
 #include "constant.h"
 /*--------------------------------------------------------------------------*/
-	char*	utos(unsigned,char*,int);
-	char*	itos(int,char*,int,int);
 	char*	ftos(double,int,int,int);
 /*--------------------------------------------------------------------------*/
 const int POOLSIZE = 100;
 const int MAXLENGTH = 40;
 static double ftos_floor = 1e-99;
 /*--------------------------------------------------------------------------*/
-char* utos(unsigned num, char *str, int len)
-{
-  if (len==0) {
-    return str;				/* reject zero length  */
-  }
-
-  int ii = std::abs(len);
-  do{					/* build string starting at tail  */
-    str[--ii] = static_cast<char>(num % 10 + '0');
-  }while ( (num/=10)>0 && ii>0 );
-  
-  {if (len > 0) {			/* if right justify, fill with blank */
-    while (ii > 0) {
-      str[--ii] = ' ';
-    }
-  }else{
-    int jj;				/* else if left justify, move left  */
-    for (jj=0;  ii<-len;  ) {		/*    then fill with blanks	    */
-      str[jj++] = str[ii++];
-    }
-    while (jj < -len) {
-      str[jj++] = ' ';
-    }
-  }}
-  return str;
-}
-/*--------------------------------------------------------------------------*/
 std::string to_string(unsigned n)
 {
   char s[100];
@@ -81,49 +53,31 @@ std::string to_string(unsigned n)
   return s;
 }
 /*--------------------------------------------------------------------------*/
-char* itos(int num, char *str, int len, int fmt)
-{
-  char sign;
-  {if (num < 0) {
-    sign = '-';
-    num = -num;
-  }else if (fmt & ftos_SIGN) {
-    sign = '+';
-  }else{
-    sign = ' ';
-  }}
-  
-  utos(static_cast<unsigned>(num), &str[1], len);
-  int ii;
-  for (ii=1; str[ii]==' '; ++ii) {
-    ;
-  }
-  str[ii-1] = sign;
-  return str;
-}
-/*--------------------------------------------------------------------------*/
 char* ftos(double num, int fieldwidth, int len, int fmt)
-	/* num = number to convert			*/
-	/* fieldwidth = size for fixed width		*/
-	/* len = max length of new string		*/
-	/* fmt = how to format it			*/
+	// num = number to convert
+	// fieldwidth = size for fixed width, 0 for variable width
+	// len = max length of new string
+	// fmt = how to format it
 {
   if (len < 3) {
+    untested();
     len = 3;
   }
   if (len > MAXLENGTH-6) {
+    untested();
     len = MAXLENGTH-6;
   }
   if (fieldwidth > MAXLENGTH-1) {
+    untested();
     fieldwidth = MAXLENGTH-1;
   }
-
-  int expo = 0;	/* exponent				*/
-  int nnn = 0; 	/* char counter -- pos in string	*/
-
+  
   char *str;
-  {
-    static char strpool[POOLSIZE][MAXLENGTH];	/* destination string pool */
+  { /* get a buffer from the pool */
+    // BUG: It is possible to have too many buffers active
+    // then the extras are overwritten, giving bad output
+    // There are no known cases, but it is not checked.
+    static char strpool[POOLSIZE][MAXLENGTH];
     static int poolindex = 0;
     ++poolindex;
     if (poolindex >= POOLSIZE) {
@@ -132,72 +86,87 @@ char* ftos(double num, int fieldwidth, int len, int fmt)
     str = strpool[poolindex];
   }
   
-  {
-    int iii;
-    for (iii=0; iii<fieldwidth; ++iii) { /* build a clean blank string */
+  { /* build a clean blank string */
+    int string_size = std::max(fieldwidth, len+6);
+    for (int iii=0; iii<string_size; ++iii) {
       str[iii] = ' ';
     }
-    for (assert(iii==fieldwidth); iii<MAXLENGTH; ++iii) {
+    for (int iii=string_size; iii<MAXLENGTH; ++iii) {
       str[iii] = '\0';
     }
   }
   
-  {if (isinf(num) > 0) {
+#ifdef HAS_NUMERIC_LIMITS
+  if (num == std::numeric_limits<double>::infinity()) {
+    untested();
     strncpy(str," Over", 5);
-  }else if (isinf(num) < 0) {
+  }else if (num == -std::numeric_limits<double>::infinity()) {
+    untested();
     strncpy(str,"-Over", 5);
-  }else if (isnan(num)) {
+  }else if (num == std::numeric_limits<double>::quiet_NaN()) {
+    untested();
     strncpy(str," NaN", 4);
-  }else if (num == NOT_VALID) {
+  }else if (num == std::numeric_limits<double>::signaling_NaN()) {
+    untested();
+    strncpy(str," NaN", 4);
+  }else
+#endif
+  if (num == NOT_VALID) {
     strncpy(str," ??", 3);
   }else if (num == NOT_INPUT) {
     strncpy(str," NA", 3);
   }else if (num >= BIGBIG) {
     strncpy(str," Inf", 4);
   }else if (num <= -BIGBIG) {
+    untested();
     strncpy(str,"-Inf", 4);
   }else{
     if (std::abs(num) < ftos_floor) {	/* hide noise */
       num = 0.;
     }
     
-    for (int iii=len+5; iii>=0; --iii) {
-      str[iii] = ' ';			/* fill with blanks */
-    }
-    
-    {if (num == 0.) {
+    int expo = 0;	/* exponent				*/
+    int nnn = 0; 	/* char counter -- pos in string	*/
+    if (num == 0.) {
       strcpy(str, " 0.");
       nnn = strlen(str);		/* num==0 .. build string 0.000...  */
-      while (--len)
+      while (--len) {
 	str[nnn++] = '0';
+      }
       assert(expo == 0);
     }else{				/* num != 0 */
-      {if (num < 0.) {
-	str[0] = '-';			/* sign */
-	num = -num;
-      }else if (fmt & ftos_SIGN) {
-	str[0] = '+';
-      }else{
-	assert(str[0] == ' ');
-      }}
-      
-      expo = -3;
-      while (num < .001) {		/* scale to .001 - 1.0 */
-	num *= 1000.;
-	expo -= 3;
+      { // insert sign
+	if (num < 0.) {
+	  str[0] = '-';
+	  num = -num;
+	}else if (fmt & ftos_SIGN) {
+	  untested();
+	  str[0] = '+';
+	}else{
+	  assert(str[0] == ' ');
+	}
       }
-      while (num >= 1.) {
-	num *= .001;
-	expo += 3;
+      { // scale to .001 - 1.0.  adjust expo.
+	expo = -3;
+	while (num < .001) {
+	  num *= 1000.;
+	  expo -= 3;
+	}
+	while (num >= 1.) {
+	  num *= .001;
+	  expo += 3;
+	}
       }
-      if ((fmt&ftos_EXP && expo<-9) || expo>10 || expo<-16) {
-	--len;				/* one less digit if 'e' notation */
-      }					/* and exp is 2 digits */
-      if (len < 3) {
-	++len;
+      { // adjust len to compensate for length of printed exponent
+	if ((fmt&ftos_EXP && expo<-9) || expo>10 || expo<-16) {
+	  --len;			/* one less digit if 'e' notation */
+	}				/* and exp is 2 digits */
+	if (len < 3) {
+	  untested();
+	  ++len;
+	}
       }
-      
-      {
+      { // round to correct number of digits
 	double rnd = .5 / pow(10., len); /* find amt to add to round */
 	if (num < .01) {
 	  rnd /= 100.;
@@ -210,70 +179,79 @@ char* ftos(double num, int fieldwidth, int len, int fmt)
 	  expo += 3;
 	}
       }
-      
-      nnn = 1;
-      {if (expo == -3) {		/* exp is -3. */
-	int flg = 0;
-	expo = 0;			/* print in fixed point, no exponent*/
-	str[nnn++] = '0';
-	str[nnn++] = '.';
-	while (len > 0) {
-	  num *= 10.;
-	  int dig = static_cast<int>(floor(num));
-	  num -= static_cast<double>(dig);
-	  str[nnn++] = static_cast<char>(dig + '0');
-	  if ((flg += dig))
-	    --len;
-	}
-      }else{
-	int flg = 0;
-	for (int iii=2; len>0; --iii) {	/* mantissa			    */
-	  num *= 10.;			/* get next digit		    */
-	  int dig = static_cast<int>(floor(num));
-	  num -= static_cast<double>(dig);/* subtract off last digit	    */
-	  if ((flg += dig)) {		/* if int part !=0		    */
-	    str[nnn++]=static_cast<char>(dig)+'0';/*(not all zeros so far)  */
-	    --len;			/* stuff the digit into the string  */
+      { // build mantissa
+	nnn = 1;
+	if (expo == -3) {		/* .001 is preferable to 1e-3 */
+	  int flg = 0;			/* print in fixed point, no exponent*/
+	  expo = 0;
+	  str[nnn++] = '0';
+	  str[nnn++] = '.';
+	  while (len > 0) {
+	    num *= 10.;
+	    int digit = static_cast<int>(floor(num));
+	    num -= static_cast<double>(digit);
+	    str[nnn++] = static_cast<char>(digit + '0');
+	    if ((flg += digit)) {
+	      --len;
+	    }
+	  }
+	}else{
+	  int flg = 0;
+	  for (int iii=2; len>0; --iii) {/* mantissa			    */
+	    num *= 10.;			/* get next digit		    */
+	    int digit = static_cast<int>(floor(num));
+	    num -= static_cast<double>(digit);/* subtract off last digit    */
+	    if ((flg += digit)) {	/* if int part !=0		    */
+	     str[nnn++]=static_cast<char>(digit)+'0';/*(not all zeros so far)*/
+	     --len;			/* stuff the digit into the string  */
+	    }
+	    if (iii==0) {		/* if we found the dec.pt. and	    */
+	      str[nnn++] = '.';		/*   haven't used up all the space  */
+	    }				/* put a dec.pt. in the string	    */
 	  }
-	  if (iii==0) {			/* if we found the dec.pt. and	    */
-	    str[nnn++] = '.';		/*   haven't used up all the space  */
-	  }				/* put a dec.pt. in the string	    */
 	}
-      }}
-    }}
+      }
+    }
+    assert(nnn > 0);
+    assert(str[nnn] == ' ' || str[nnn] == '\0');
     
-    if (!(fmt&ftos_FILL)) {		/* supress trailing zeros */
-      while (str[nnn-1]=='0') {
-	str[--nnn] = static_cast<char>((nnn<fieldwidth) ? ' ' : '\0');
+    { // suppress trailing zeros
+      if (!(fmt&ftos_FILL)) {
+	while (str[--nnn]=='0') {
+	  str[nnn] = static_cast<char>((nnn < fieldwidth) ? ' ' : '\0');
+	}
+	++nnn;
+      }else{
+	untested();
       }
     }
     
-    if (expo == 0) {
-      return str;
-    }
-    
-    {if (fmt&ftos_EXP || expo>10 || expo<-16) {	/* if exponential format  */
-      str[nnn++] = 'E';				/* put the letter 'E' and */
-      {if (expo < 100) {			/* convert the exponent   */
-	itos(expo, &str[nnn], -2, ftos_SIGN);
-      }else{
-	utos(static_cast<unsigned>(expo), &str[nnn], -3);
-      }}
-    }else{				   /* if letter-scale format	    */
-      str[nnn++] = "fpnum KMGT"[(expo+15)/3];/* put the appropriate letter  */
-    }}				/* note that letter-scale is not valid	    */
+    { // append exponent
+      if (expo == 0) {
+	// nothing;
+      }else if (fmt&ftos_EXP || expo>10 || expo<-16) {/* exponential format  */
+	char c = str[nnn+4];
+	sprintf(&str[nnn], ((expo < 100) ? "E%+-3d" : "E%3u"), expo);
+	nnn+=4;
+	str[nnn++] = c;
+      }else{				   /* if letter-scale format	    */
+	str[nnn++] = "fpnum KMGT"[(expo+15)/3];/* put the appropriate letter*/
+      }				/* note that letter-scale is not valid	    */
 				/* for exp==-3 or exp not in -15..+12	    */
 				/* this is trapped but letter-scale is also */
 				/* not valid if exp not divisible by 3.     */
 				/* This is not trapped, since it supposedly */
 				/* cant happen.				    */
-    if (str[nnn-1] == 'M') {
-      str[nnn++] = 'e';
-      str[nnn++] = 'g';
+      if (str[nnn-1] == 'M') {
+	str[nnn++] = 'e';	/* Spice kluge "MEG" */
+	str[nnn++] = 'g';
+      }
+    }
+  }
+  { // clean up trailing blanks
+    if (fieldwidth==0) {
+      trim(str);
     }
-  }}
-  if (fieldwidth==0) {		/* BUG: this cleans up stray trailing	*/
-    trim(str);			/* blanks.  I don't know why they exist	*/
   }
   
   return str;
