@@ -1,4 +1,4 @@
-/*$Id: l_pmatch.cc,v 21.14 2002/03/26 09:20:25 al Exp $ -*- C++ -*-
+/*$Id: l_pmatch.cc,v 25.94 2006/08/08 03:22:25 al Exp $ -*- C++ -*-
  * Copyright (C) 2001 Albert Davis
  * Author: Albert Davis <aldavis@ieee.org>
  *
@@ -16,8 +16,8 @@
  *
  * You should have received a copy of the GNU General Public License
  * along with this program; if not, write to the Free Software
- * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA
- * 02111-1307, USA.
+ * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA
+ * 02110-1301, USA.
  *------------------------------------------------------------------
  * string compare
  * compares characters until end of first string
@@ -28,11 +28,8 @@
  * Characters in reference string in UPPER case must match.
  * Always requires at least one character to match.
  */
+//testing=script,complete 2006.07.13
 #include "ap.h"
-/*--------------------------------------------------------------------------*/
-	int	pmatch(const char*,const char*);
-/*--------------------------------------------------------------------------*/
-static inline int is_alpha(int c){return isalpha(toascii(c));}
 /*--------------------------------------------------------------------------*/
 /* pmatch: match str1 (under test) against str2 (reference)
  * if no match, returns 0
@@ -50,11 +47,11 @@ static inline int is_alpha(int c){return isalpha(toascii(c));}
 int pmatch(const char* str1, const char* str2)
 {
   CS cmd(str1);
-  {if (cmd.pmatch(str2)){
+  if (cmd.pmatch(str2)) {
     return cmd.cursor();
   }else{
     return 0;
-  }}
+  }
 }
 /*--------------------------------------------------------------------------*/
 /*--------------------------------------------------------------------------*/
