@@ -1,4 +1,4 @@
-/*$Id: l_trim.cc,v 21.14 2002/03/26 09:20:25 al Exp $ -*- C++ -*-
+/*$Id: l_trim.cc,v 25.94 2006/08/08 03:22:25 al Exp $ -*- C++ -*-
  * Copyright (C) 2001 Albert Davis
  * Author: Albert Davis <aldavis@ieee.org>
  *
@@ -16,21 +16,23 @@
  *
  * You should have received a copy of the GNU General Public License
  * along with this program; if not, write to the Free Software
- * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA
- * 02111-1307, USA.
+ * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA
+ * 02110-1301, USA.
  *------------------------------------------------------------------
  * remove whitespace from the end of strings
  */
-#include <string.h>
-#include <ctype.h>
+//testing=script,complete 2006.07.13
+#include <cstring>
+#include <cctype>
 /*--------------------------------------------------------------------------*/
 	char*	trim(char*);
 /*--------------------------------------------------------------------------*/
 char* trim(char *string)
 {
   int idx = strlen(string);
-  while (idx > 0  &&  !isgraph(string[--idx]))
+  while (idx > 0  &&  !isgraph(string[--idx])) {
     string[idx] = '\0' ;
+  }
   return string;
 }
 /*--------------------------------------------------------------------------*/
