@@ -1,4 +1,4 @@
-/*$Id: l_wmatch.cc,v 21.14 2002/03/26 09:20:25 al Exp $ -*- C++ -*-
+/*$Id: l_wmatch.cc,v 25.94 2006/08/08 03:22:25 al Exp $ -*- C++ -*-
  * Copyright (C) 2001 Albert Davis
  * Author: Albert Davis <aldavis@ieee.org>
  *
@@ -16,8 +16,8 @@
  *
  * You should have received a copy of the GNU General Public License
  * along with this program; if not, write to the Free Software
- * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA
- * 02111-1307, USA.
+ * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA
+ * 02110-1301, USA.
  *------------------------------------------------------------------
  * wmatch: string match with wild cards
  * s1 may have wild cards: ? any character matches; * any repeated 0 or more
@@ -26,13 +26,15 @@
  *	but \ before any letter in s1 forces exact match
  * recursive
  */
-#include <ctype.h>
+//testing=script 2006.07.13
+#include <cctype>
+#include "md.h"
 /*--------------------------------------------------------------------------*/
 	bool	wmatch(const char*,const char*);
 /*--------------------------------------------------------------------------*/
 bool wmatch(const char *s2, const char *s1)
 {
-  {if (!*s2 && !*s1) {			// both end together -- match
+  if (!*s2 && !*s1) {			// both end together -- match
     return true;
   }else if (!*s2 || !*s1) {		// ends don't match
     return false;
@@ -41,16 +43,16 @@ bool wmatch(const char *s2, const char *s1)
   }else if (*s1 == '?') {		// ? wild card match - move on
     return wmatch(s2+1, s1+1);
   }else if (*s1 == '*') {		// * (repeat) wild card match
-    {if (wmatch(s2+1, s1)) {		// match 1, try for 2
+    if (wmatch(s2+1, s1)) {		// match 1, try for 2
       return true;
-    }else if (wmatch(s2, s1+1)) {	// match 0 - continue
+    }else if (wmatch(s2, s1+1)) {untested();	// match 0 - continue
       return true;
     }else{				// match 1, only 1
       return wmatch(s2+1, s1+1);
-    }}
+    }
   }else{				// mismatch
     return false;
-  }}
+  }
 }
 /*--------------------------------------------------------------------------*/
 /*--------------------------------------------------------------------------*/
