@@ -1,4 +1,4 @@
-/*$Id: m_divdiff.h,v 21.14 2002/03/26 09:20:25 al Exp $ -*- C++ -*-
+/*$Id: m_divdiff.h,v 25.94 2006/08/08 03:22:25 al Exp $ -*- C++ -*-
  * Copyright (C) 2001 Albert Davis
  * Author: Albert Davis <aldavis@ieee.org>
  *
@@ -16,8 +16,8 @@
  *
  * You should have received a copy of the GNU General Public License
  * along with this program; if not, write to the Free Software
- * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA
- * 02111-1307, USA.
+ * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA
+ * 02110-1301, USA.
  *------------------------------------------------------------------
  * divided differences
  * in:
@@ -26,17 +26,33 @@
  *   n = size of array
  *   # of divided differences == n-1
  * out:
- *   c = differences (approx derivatives)
+ *   c = "divided differences" (mult by n! to get derivative)
  */
+//testing=script,complete 2006.07.13
 /*--------------------------------------------------------------------------*/
+#if 0
 template<class T1, class T2>
 inline void divided_differences(T1 c[], int n, const T2 t[])
 {
-  for (int d=1; d<n; ++d){
-    for (int i=n-1; i>=d; --i){
+  untested();
+  for (int d=1; d<n; ++d) {
+    untested();
+    for (int i=n-1; i>=d; --i) {
+      untested();
       c[i] = (c[i-1] - c[i]) / (t[i-d] - t[i]);
     }
   }
 }
+#endif
+/*--------------------------------------------------------------------------*/
+template<class T1, class T2>
+inline void derivatives(T1 c[], int n, const T2 t[])
+{
+  for (int d=1; d<n; ++d) {
+    for (int i=n-1; i>=d; --i) {
+      c[i] = d * (c[i-1] - c[i]) / (t[i-d] - t[i]);
+    }
+  }
+}
 /*--------------------------------------------------------------------------*/
 /*--------------------------------------------------------------------------*/
