@@ -1,4 +1,4 @@
-/*$Id: s_ac.cc,v 21.14 2002/03/26 09:20:25 al Exp $ -*- C++ -*-
+/*$Id: s_ac.cc,v 25.94 2006/08/08 03:22:25 al Exp $ -*- C++ -*-
  * Copyright (C) 2001 Albert Davis
  * Author: Albert Davis <aldavis@ieee.org>
  *
@@ -16,12 +16,12 @@
  *
  * You should have received a copy of the GNU General Public License
  * along with this program; if not, write to the Free Software
- * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA
- * 02111-1307, USA.
+ * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA
+ * 02110-1301, USA.
  *------------------------------------------------------------------
  * ac analysis top
  */
-#include "u_opt.h"
+//testing=script 2006.07.14
 #include "u_status.h"
 #include "s_ac.h"
 /*--------------------------------------------------------------------------*/
@@ -31,19 +31,26 @@ void AC::command(CS& cmd)
 {
   mode = sAC;
   reset_timers();
-  STATUS::ac.reset().start();
+  ::status.ac.reset().start();
+
   init();
   alloc_vectors();
-  acx.allocate().set_min_pivot(OPT::pivtol);
+  
+  acx.reallocate();
+  acx.set_min_pivot(OPT::pivtol);
+  
   setup(cmd);
-  STATUS::set_up.stop();
-  switch (ENV::run_mode){
-  case rINTERACTIVE:
-  case rSCRIPT:
+  ::status.set_up.stop();
+  switch (ENV::run_mode) {
   case rBATCH:
+    untested();
+  case rINTERACTIVE:
+    untested();
+  case rSCRIPT:
     sweep();
     break;
   case rIGNORE:
+    untested();
   case rPRESET:
     /*nothing*/
     break;
@@ -51,8 +58,8 @@ void AC::command(CS& cmd)
   acx.unallocate();
   unalloc_vectors();
   
-  STATUS::ac.stop();
-  STATUS::total.stop();
+  ::status.ac.stop();
+  ::status.total.stop();
 }
 /*--------------------------------------------------------------------------*/
 /*--------------------------------------------------------------------------*/
