@@ -1,4 +1,4 @@
-/*$Id: s_dc.cc,v 21.14 2002/03/26 09:20:25 al Exp $ -*- C++ -*-
+/*$Id: s_dc.cc,v 25.94 2006/08/08 03:22:25 al Exp $ -*- C++ -*-
  * Copyright (C) 2001 Albert Davis
  * Author: Albert Davis <aldavis@ieee.org>
  *
@@ -16,12 +16,12 @@
  *
  * You should have received a copy of the GNU General Public License
  * along with this program; if not, write to the Free Software
- * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA
- * 02111-1307, USA.
+ * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA
+ * 02110-1301, USA.
  *------------------------------------------------------------------
  * dc analysis top
  */
-#include "u_status.h"
+//testing=script,complete 2006.07.14
 #include "s_dc.h"
 /*--------------------------------------------------------------------------*/
 //	void	DC::command(CS&);
@@ -32,9 +32,9 @@ void DC::command(CS& cmd)
   time0 = 0.;
   mode = sDC;
   phase = pINIT_DC;
-  STATUS::dc.reset().start();
+  ::status.dc.reset().start();
   command_base(cmd);
-  STATUS::dc.stop();
+  ::status.dc.stop();
 }
 /*--------------------------------------------------------------------------*/
 void OP::command(CS& cmd)
@@ -42,9 +42,9 @@ void OP::command(CS& cmd)
   time0 = 0.;
   mode = sOP;
   phase = pINIT_DC;
-  STATUS::op.reset().start();
+  ::status.op.reset().start();
   command_base(cmd);
-  STATUS::op.stop();
+  ::status.op.stop();
 }
 /*--------------------------------------------------------------------------*/
 /*--------------------------------------------------------------------------*/
