@@ -1,4 +1,4 @@
-/*$Id: u_probe.h,v 21.14 2002/03/26 09:20:25 al Exp $ -*- C++ -*-
+/*$Id: u_probe.h,v 25.94 2006/08/08 03:22:25 al Exp $ -*- C++ -*-
  * Copyright (C) 2001 Albert Davis
  * Author: Albert Davis <aldavis@ieee.org>
  *
@@ -16,11 +16,12 @@
  *
  * You should have received a copy of the GNU General Public License
  * along with this program; if not, write to the Free Software
- * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA
- * 02111-1307, USA.
+ * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA
+ * 02110-1301, USA.
  *------------------------------------------------------------------
  * single probe item
  */
+//testing=script,complete 2006.07.14
 #ifndef U_PROBE_H
 #define U_PROBE_H
 #include "l_compar.h" // inorder
@@ -31,11 +32,11 @@ class PROBE {
 private:
   std::string	_what;    
   int		_node;
-  CKT_BASE*	_brh;
+  const CKT_BASE* _brh;
   double	_lo,_hi;
 public:
   explicit  PROBE(const std::string& what, int node, double lo=0, double hi=0);
-  explicit  PROBE(const std::string& what, CKT_BASE *brh,
+  explicit  PROBE(const std::string& what, const CKT_BASE *brh,
 		  double lo=0, double hi=0);
 	    PROBE(const PROBE& p);
 	    ~PROBE()				{detach();}
@@ -44,10 +45,6 @@ public:
   void	    detach();
   PROBE&    operator=(const PROBE& p);
 
-  bool      operator<(const PROBE&)const;
-  bool	    operator==(const PROBE&)const;
-  bool	    operator!=(const PROBE& p)const	{return !(*this == p);}
-  
   const std::string label()const;
   double	  value()const;
   const CKT_BASE* object()const	 {return _brh;}
